@@ -5,18 +5,17 @@
 
 import tempfile as _tempfile
 import warnings as _warnings
+from typing import Optional, Text, Tuple
 
 from coremltools.converters._profile_utils import _profile
+from coremltools.converters.mil import Program
 from coremltools.converters.mil.mil import Builder as mb
-from coremltools.converters.mil.mil.passes.quantization_passes import \
-    AbstractQuantizationPass
-from coremltools.converters.mil.mil.types.symbolic import (k_num_internal_syms,
-                                                           k_used_symbols)
+from coremltools.converters.mil.mil.types.symbolic import k_num_internal_syms, k_used_symbols
 from coremltools.models import MLModel
 from coremltools.models.model import _create_mlpackage
 
 from . import ImageType, InputType
-from .mil.passes.apply_common_pass_pipeline import apply_common_pass_pipeline
+from .mil.passes.pass_pipeline import PassPipeline, PipelineManager
 
 
 class ConverterRegistry:
@@ -104,7 +103,7 @@ class TorchFrontend:
     name = "pytorch"
 
     def __call__(self, *args, **kwargs):
-        from .frontend.torch import load
+        from .frontend.torch.load import load
 
         return load(*args, **kwargs)
 
@@ -115,17 +114,18 @@ class NNProtoBackend:
     alias_names = []
 
     def __call__(self, *args, **kwargs):
-        from .backend.nn import load
+        from .backend.nn.load import load
 
         return load(*args, **kwargs)
 
+
 @ConverterRegistry.backend
 class MILProtoBackend:
     name = "mlprogram"
     alias_names = []
 
     def __call__(self, *args, **kwargs):
-        from .backend.mil import load as backend_load
+        from .backend.mil.load import load as backend_load
 
         return backend_load(*args, **kwargs)
 
@@ -145,6 +145,7 @@ def _reset_conversion_state():
     k_used_symbols.clear()
     k_num_internal_syms = 0
 
+
 @_profile
 def mil_convert(
     model,
@@ -242,12 +243,8 @@ def _mil_convert(
 
 
 def mil_convert_to_proto(
-    model,
-    convert_from,
-    convert_to,
-    converter_registry,
-    **kwargs
-):
+    model, convert_from, convert_to, converter_registry, main_pipeline=None, **kwargs
+) -> Tuple[Optional[MLModel], Program]:
     """
     Convert model to proto object.
 
@@ -262,42 +259,83 @@ def mil_convert_to_proto(
     converter_registry: `ConverterRegistry`
       Available frontend and backend converters
 
-    Returns
-    -------
-    model: `coremltools.models.MLModel` or
-    `coremltools.converters.mil.Program`
-        See `coremltools.converters.convert`
+    main_pipeline: `PassPipeline`
+      The main pipeline with options set by users.
     """
     frontend_converter_type = converter_registry.frontends.get(convert_from.lower())
     if not frontend_converter_type:
-        msg = 'Frontend converter "{}" not implemented, must be one of: {}'
         raise NotImplementedError(
-            msg.format(convert_from, list(converter_registry.frontends.keys()))
+            f'Frontend converter "{convert_from}" not implemented, must be '
+            f"one of: {list(converter_registry.frontends.keys())}"
         )
 
     kwargs.setdefault("convert_to", convert_to)
+
+    if main_pipeline is None:
+        # If the client calls `mil_convert` directly, the `pass_pipeline` is None. To keep the
+        # behaviour same as before, the quantization pass is removed in this situation.
+        # TODO: rdar://106111553 ([Infra] Quantization Pass is skipped when `mil_convert` is called directly.)
+        main_pipeline = PassPipeline()
+        main_pipeline.remove_passes({"common::add_fp16_cast"})
+    frontend_pipeline, backend_pipeline = _construct_other_pipelines(
+        main_pipeline, convert_from, convert_to
+    )
+
     frontend_converter = frontend_converter_type()
-
     prog = frontend_converter(model, **kwargs)
+    PipelineManager.apply_pipeline(prog, frontend_pipeline)
 
-    if convert_to.lower() != "neuralnetwork":
-        passes = kwargs.get("transforms", list())
-    else:
-        # Post training Quantization Passes not available on NN proto backend.
-        passes = [p for p in kwargs.get("transforms", list()) if not isinstance(p, AbstractQuantizationPass)]
+    PipelineManager.apply_pipeline(prog, main_pipeline)
 
-    apply_common_pass_pipeline(prog, passes)
+    prog._check_invalid_tensor_rank()
 
     if convert_to == 'milinternal':
-        return None, prog # Returns (None, coremltools.converters.mil.Program)
+        return None, prog
 
+    PipelineManager.apply_pipeline(prog, backend_pipeline)
     backend_converter_type = converter_registry.backends.get(convert_to.lower())
     if not backend_converter_type:
-        msg = 'Backend converter "{}" not implemented, must be one of: {}'
         raise NotImplementedError(
-            msg.format(convert_to, list(converter_registry.backends.keys()))
+            f'Backend converter "{convert_to}" not implemented, must be '
+            f"one of: {list(converter_registry.backends.keys())}"
         )
     backend_converter = backend_converter_type()
     out = backend_converter(prog, **kwargs)
 
-    return out, prog # Returns (Model_pb2.Model, coremltools.converters.mil.Program)
+    return out, prog
+
+
+def _construct_other_pipelines(
+    main_pipeline: PassPipeline, convert_from: Text, convert_to: Text
+) -> Tuple[PassPipeline, PassPipeline]:
+    """
+    Construct other pipelines based on the main pipeline. It includes:
+    - The frontend pipeline which will run in the frontend converter
+    - The backend pipeline which will run in the backend converter
+    As the main pipeline could have passes which also exists in the frontend/backend passes, we
+    need to make sure the pass options are set properly in all pipelines.
+    For example, if users set options to skip some vars in `const_elimination` pass, we want to make
+    sure those vars are skipped not only in main_pipeline, but also in other pipelines wherever the
+    `const_elimination` pass runs.
+
+    TODO: rdar://106046237 ([Infra] Expose Backend and Frontend Pipeline to External Users)
+    Currently users only control the passes in the main pipeline by passing `pass_pipeline` param.
+    There are two reasons why we don't expose the frontend/backend pipelines at the current stage:
+    - The frontend and backend specific passes need to be well documented.
+    - The interface need more carefully design, as we don't want to provide too many params such as
+      ct.convert(..., frontend_pipeline=xxx, backend_pipelien=xxx, main_pipeline=xxx) to overwhelm
+      users.
+    """
+    # Set the main pipeline options specified by the user in frontend/backend pipeline.
+    frontend_pipeline = PassPipeline.get_pipeline(f"frontend_{convert_from.lower()}")
+    frontend_pipeline.set_options_by_another_pipeline(main_pipeline)
+    backend_pipeline = PassPipeline.get_pipeline(f"backend_{convert_to.lower()}")
+    backend_pipeline.set_options_by_another_pipeline(main_pipeline)
+
+    # If a pass is skipped in the main pipeline, we also skip it in the frontend/backend pipeline.
+    default_main_pipeline = PassPipeline.get_pipeline("default")
+    passes_skipped_in_main = set(default_main_pipeline.passes) - set(main_pipeline.passes)
+    frontend_pipeline.remove_passes(passes_skipped_in_main)
+    backend_pipeline.remove_passes(passes_skipped_in_main)
+
+    return frontend_pipeline, backend_pipeline
