@@ -313,17 +313,10 @@ class Operation:
                         )
                     else:
                         new_var = Var(name, sym_type, sym_val, op=self, op_output_idx=i)
-                    if new_var.rank >= 6:
-                        raise ValueError(
-                            f'Core ML only supports tensors with rank <= 5. Layer "{self.name}", '
-                            f'with type "{self.op_type}", outputs a rank {new_var.rank} tensor. '
-                        )
                 self._output_vars.append(new_var)
         else:
             # Check new inference result against existing self._output_vars.
-            for i, (n, sym_type, sym_val) in enumerate(
-                zip(output_names, output_types, output_vals)
-            ):
+            for i, (sym_type, sym_val) in enumerate(zip(output_types, output_vals)):
                 out_var = self._output_vars[i]
                 # Check type inference
                 if overwrite_output:
@@ -453,7 +446,7 @@ class Operation:
 
     def _ensure_required_inputs(self):
         """
-        Raise value error if required inputs aren't present
+        Raises ValueError if required inputs are not present
         """
         for name, input_type in self._input_types.items():
             if not input_type.optional and self._input_vars[name] is None:
