@@ -5,14 +5,9 @@
 
 import numpy as np
 
-from coremltools.converters.mil.mil import (
-    DefaultInputs,
-    get_new_symbol,
-    InputSpec,
-    Operation,
-    TensorInputType,
-    types,
-)
+from coremltools.converters.mil.mil import (DefaultInputs, InputSpec,
+                                            Operation, TensorInputType,
+                                            get_new_symbol, types)
 from coremltools.converters.mil.mil.ops.defs._op_reqs import register_op
 from coremltools.converters.mil.mil.ops.defs.iOS15 import _IOS15_TARGET
 from coremltools.converters.mil.mil.types.symbolic import is_symbolic
@@ -469,13 +464,13 @@ class crop_resize(Operation):
           coordinate corresponds to the top-left corner of the image.
         * This parameter can take one of four values:
 
-          "CORNERS_HEIGHT_FIRST": ``[h_start, w_start, h_end, w_end]``
+          ``"CORNERS_HEIGHT_FIRST"``: ``[h_start, w_start, h_end, w_end]``
 
-          "CORNERS_WIDTH_FIRST": ``[w_start, h_start, w_end, h_end]``
+          ``"CORNERS_WIDTH_FIRST"``: ``[w_start, h_start, w_end, h_end]``
 
-          "CENTER_SIZE_HEIGHT_FIRST": ``[h_center, w_center, box_height, box_width]``
+          ``"CENTER_SIZE_HEIGHT_FIRST"``: ``[h_center, w_center, box_height, box_width]``
 
-          "CENTER_SIZE_WIDTH_FIRST": ``[w_center, h_center, box_width, box_height]``
+          ``"CENTER_SIZE_WIDTH_FIRST"``: ``[w_center, h_center, box_width, box_height]``
 
     sampling_mode : const<str> (Optional, default="DEFAULT")
         * This parameter can take ``"STRICT_ALIGN_CORNERS"``,
@@ -584,8 +579,8 @@ class crop(Operation):
     -------
     tensor<[\*D, H2, W2],T>
         * Tensor with same type as the input.
-        * ``H2`` = ``H1`` - crop_height[0] - crop_height[1].
-        * ``W2`` = ``W1`` - crop_width[0] - crop_width[1].
+        * ``H2`` = ``H1 - crop_height[0] - crop_height[1]``.
+        * ``W2`` = ``W1 - crop_width[0] - crop_width[1]``.
 
     Attributes
     ----------
@@ -644,11 +639,11 @@ class affine(Operation):
     value at the coordinate ``(x’,y’)`` in the input image using either bilinear or
     nearest neighbor interpolation. If the ``(x’, y’)`` point falls outside the input
     image, then padding information is used to compute the value.
-    
-    .. sourcecode:: python
 
-        * x’ = a0 * x + a1 * y + a2
-        * y’ = b0 * x + b1 * y + b2
+    ::
+
+        x’ = a0 * x + a1 * y + a2
+        y’ = b0 * x + b1 * y + b2
 
 
     Parameters
@@ -792,7 +787,7 @@ class resample(Operation):
         * Coordinate (normalized or unnormalized) should be specified according
           to ``coordinates_mode``.
     sampling_mode: const<str>
-        * Allowed values: ``"bilinear" , "nearest"``
+        * Allowed values: ``"bilinear"`` , ``"nearest"``
     padding_mode: const<str>
         * Allowed values: ``"constant"``, ``"border"``, ``"reflection"``, ``"symmetric"``
         * Note that the following example is 1D case for brevity.
