@@ -8,12 +8,14 @@ import itertools
 import numpy as np
 import pytest
 
-from .testing_utils import UNK_SYM, run_compare_builder
 import coremltools as ct
-from coremltools.converters.mil.mil import Builder as mb, types
+from coremltools.converters.mil.mil import Builder as mb
+from coremltools.converters.mil.mil import get_new_symbol, types
 from coremltools.converters.mil.testing_reqs import backends, compute_units
 from coremltools.converters.mil.testing_utils import ssa_fn
 
+from .testing_utils import UNK_SYM, run_compare_builder
+
 
 class TestSliceByIndex:
     @pytest.mark.parametrize(
@@ -50,6 +52,63 @@ class TestSliceByIndex:
             backend=backend,
         )
 
+    def test_type_inference(self):
+        s0 = get_new_symbol()
+        s1 = get_new_symbol()
+        s2 = get_new_symbol()
+
+        input_placeholders = {
+            "x": mb.placeholder(shape=(10, s0, s1, s2)),
+        }
+
+        def build(x):
+            return [
+                mb.slice_by_index(
+                    x=x, begin=[2, 5, 6, 12], end=[6, 9, 20, -9], stride=[2, 1, 2, 1]
+                ),
+                mb.slice_by_index(
+                    x=x,
+                    begin=[-2, -5, -3, 9],
+                    end=[-6, -9, -6, -7],
+                    stride=[-2, -1, -2, 1],
+                ),
+                mb.slice_by_index(
+                    x=x,
+                    begin=[0, 0, 0, 0],
+                    end=[-6, -9, 3, -2],
+                    stride=[-2, -3, 1, 2],
+                    begin_mask=[True, True, True, True],
+                    end_mask=[False, False, False, False],
+                ),
+                mb.slice_by_index(
+                    x=x,
+                    begin=[-2, 5, -1, -7],
+                    end=[0, 0, 0, 0],
+                    stride=[-2, -3, 1, -2],
+                    begin_mask=[False, False, False, False],
+                    end_mask=[True, True, True, True],
+                ),
+                mb.slice_by_index(
+                    x=x, begin=[4, -1, 0, -5], end=[4, -1, 0, -5], stride=[1, -1, 2, -2]
+                ),
+            ]
+
+        expected_output_types = [
+            (2, 4, 7, UNK_SYM, types.fp32),
+            (2, 4, 2, UNK_SYM, types.fp32),
+            (3, 3, 3, UNK_SYM, types.fp32),
+            (5, 2, 1, UNK_SYM, types.fp32),
+            (0, 0, 0, 0, types.fp32),
+        ]
+
+        run_compare_builder(
+            build,
+            input_placeholders,
+            expected_output_types=expected_output_types,
+            frontend_only=True,
+        )
+
+
     @pytest.mark.xfail(reason="rdar://99664032")
     @pytest.mark.parametrize(
         "compute_unit, backend", itertools.product(compute_units, backends,)
@@ -83,26 +142,49 @@ class TestSliceByIndex:
             backend=backend,
         )
 
+    @ssa_fn
+    def test_builder_eval_scalar_output_corner_cases(self):
+        x1 = np.array([2.])
+        x2 = np.array([[[[1.],[3.]]]])
+        v = [
+            mb.slice_by_index(
+                x=x1, begin=[0,], end=[0], squeeze_mask=[True],
+            ), 
+            mb.slice_by_index(
+                x=x2, begin=[0, 0, 0, 0], end=[0, 0, 0, 0], squeeze_mask=[True, True, True, True],
+            ), 
+        ]
+        assert v[0].val.shape == ()
+        assert v[0].val == 2
+        assert v[1].val.shape == ()
+        assert v[1].val == 1
+
     @ssa_fn
     def test_builder_eval(self):
         x_val = np.array(list(range(24))).reshape((2, 3, 4))
         v = [
-            mb.slice_by_index(x=x_val, begin=[1, 1, 1], end=[2, 2, 2]),
+            mb.slice_by_index(
+                x=x_val, begin=[1, 1, 1], end=[2, 2, 2]
+            ),  # x_val[1:2, 1:2, 1:2]
             mb.slice_by_index(
                 x=x_val, begin=[1, 1, 1], end=[2, 3, 4], stride=[1, 1, 2]
-            ),
-            mb.slice_by_index(x=x_val, begin=[-3, -3, -3], end=[-1, -1, -1]),
-            mb.slice_by_index(x=x_val, begin=[0, 0, -3], end=[-1, -2, -2]),
+            ),  #  x_val[1:2, 1:3, 1:4:2]
+            mb.slice_by_index(
+                x=x_val, begin=[-3, -3, -3], end=[-1, -1, -1]
+            ),  # x_val[-3:-1, -3:-1, -3:-1]
+            mb.slice_by_index(
+                x=x_val, begin=[0, 0, -3], end=[-1, -2, -2]
+            ),  # x_val[0:-1, 0:-2, -3:-2]
             mb.slice_by_index(
                 x=x_val, begin=[-1, -1, -1], end=[0, 1, -3], stride=[-2, -1, -3]
-            ),
+            ),  # x_val[-1:0:-2, -1:1:-1, -1:-3:-3]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 1, 1],
                 end=[2, 3, 4],
                 stride=[1, 1, 2],
                 begin_mask=[True, False, True],
-            ),
+            ),  # x_val[:2, 1:3, :4:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 1, 1],
@@ -110,7 +192,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 2],
                 begin_mask=[True, False, True],
                 end_mask=[True, True, False],
-            ),
+            ),  # x_val[:, 1:, :4:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 1, 1],
@@ -119,7 +201,7 @@ class TestSliceByIndex:
                 begin_mask=[False, False, True],
                 end_mask=[True, False, False],
                 squeeze_mask=[False, True, False],
-            ),
+            ),  # x_val[1::1, 1, :3:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 0],
@@ -127,14 +209,14 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[True, True, True],
                 end_mask=[True, True, True],
-            ),
+            ),  # x_val[:, :, :]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 1, 1],
                 end=[2, 2, 0],
                 stride=[1, 1, 1],
                 squeeze_mask=[False, False, True],
-            ),
+            ),  # x_val[1:2, 1:2, 1]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 0, 0],
@@ -142,7 +224,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[False, True, True],
                 end_mask=[False, True, True],
-            ),
+            ),  # x_val[1:2, ...]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 0],
@@ -150,7 +232,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[True, True, True],
                 end_mask=[True, True, True],
-            ),
+            ),  # x_val[...]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 0, 1],
@@ -158,7 +240,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[False, True, False],
                 end_mask=[False, True, False],
-            ),
+            ),  # x_val[1:2, ..., 1:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 1],
@@ -167,7 +249,7 @@ class TestSliceByIndex:
                 begin_mask=[True, True, False],
                 end_mask=[True, True, False],
                 squeeze_mask=[False, False, True],
-            ),
+            ),  # x_val[..., 1]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 0],
@@ -176,7 +258,7 @@ class TestSliceByIndex:
                 begin_mask=[False, False, True],
                 end_mask=[False, False, True],
                 squeeze_mask=[True, True, False],
-            ),
+            ),  # x_val[0, 0, :]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 0, 0],
@@ -184,7 +266,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[False, True, True],
                 end_mask=[False, True, True],
-            ),
+            ),  # x_val[1:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 1, 0],
@@ -192,7 +274,7 @@ class TestSliceByIndex:
                 stride=[1, 1, 1],
                 begin_mask=[False, False, True],
                 end_mask=[False, False, True],
-            ),
+            ),  # x_val[1:2, 1:2]
             mb.slice_by_index(
                 x=x_val,
                 begin=[1, 0, 0],
@@ -201,14 +283,14 @@ class TestSliceByIndex:
                 begin_mask=[False, True, True],
                 end_mask=[False, True, True],
                 squeeze_mask=[True, False, False],
-            ),
+            ),  # x_val[1]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 0],
                 end=[0, 0, 0],
                 begin_mask=[True, True, True],
                 end_mask=[True, True, True],
-            ),
+            ),  # x_val[:]
             mb.slice_by_index(
                 x=x_val,
                 begin=[0, 0, 0],
@@ -216,7 +298,7 @@ class TestSliceByIndex:
                 stride=[1, 1, -1],
                 begin_mask=[True, True, True],
                 end_mask=[True, True, True],
-            ),
+            ),  # x_val[..., ::-1]
         ]
         ans = [
             x_val[1:2, 1:2, 1:2],
@@ -241,6 +323,7 @@ class TestSliceByIndex:
             x_val[..., ::-1],
         ]
         for idx in range(len(v)):
+            assert ans[idx].shape == v[idx].shape
             np.testing.assert_allclose(ans[idx], v[idx].val, atol=1e-04, rtol=1e-05)
 
 
