@@ -3,6 +3,8 @@
 #  Use of this source code is governed by a BSD-3-clause license that can be
 #  found in the LICENSE.txt file or at https://opensource.org/licenses/BSD-3-Clause
 
+from typing import Optional
+
 from coremltools.converters.mil.mil import types
 from coremltools.converters.mil.mil.types import builtin_to_string
 from coremltools.converters.mil.mil.types.symbolic import any_symbolic
@@ -70,7 +72,7 @@ class Var:
 
     child_ops [_child_ops]: list[Operation]
         Ops that take this Var as an input.
-        
+
     nonreplaceable_vars_upstream: set[Var]
         Set that consists of nonreplaceable vars upstream
     """
@@ -86,7 +88,14 @@ class Var:
         "_nonreplaceable_vars_upstream",
     ]
 
-    def __init__(self, name, sym_type, sym_val=None, op=None, op_output_idx=None):
+    def __init__(
+        self,
+        name,
+        sym_type,
+        sym_val=None,
+        op=None,
+        op_output_idx=None,
+    ):
         """
         sym_type (builtin type)
         sym_val (builtin value)
@@ -106,7 +115,7 @@ class Var:
         # == 0) but is still used as block output. A var can be output of
         # multiple blocks (e.g., both current block and nested blocks)
         self.consuming_blocks = list()
-        
+
         # replaceability
         self._nonreplaceable_vars_upstream = set()
         self._set_nonreplaceable_vars_upstream()
@@ -126,12 +135,12 @@ class Var:
         if op is None:
             return False
         return op.op_type.startswith("constexpr_")
-    
+
     def _set_nonreplaceable_vars_upstream(self):
         """
         A utility function to set the value of the "nonreplaceable_vars_upstream" property.
-        If the var is an output of the constexpr op, then "nonreplaceable_vars_upstream" is a single element set, containing this var.
-        Otherwise, its a union of the "nonreplaceable_vars_upstream" sets of all the input vars of its parent op.
+        If self is a non-replaceable var, then "nonreplaceable_vars_upstream" is a single element set, containing self.
+        Otherwise, it is a union of the "nonreplaceable_vars_upstream" sets of all the input vars of its parent ops.
         """
         op = self.op
         if op is None:
@@ -143,7 +152,7 @@ class Var:
             inputs_nonreplaceable_vars_upstream = [p.nonreplaceable_vars_upstream for p in flattened_inputs]
             if len(inputs_nonreplaceable_vars_upstream) > 0:
                 self.nonreplaceable_vars_upstream = set.union(*inputs_nonreplaceable_vars_upstream)
-            
+
     def _reset_nonreplaceable_vars_upstream(self):
         self.nonreplaceable_vars_upstream = set()
 
@@ -153,6 +162,17 @@ class Var:
         """
         return self.nonreplaceable_vars_upstream.issubset(new_var.nonreplaceable_vars_upstream)
 
+    def can_be_folded_to_const(self) -> bool:
+        """
+        When translating frontend ops to PyMIL ops, some vars could be directly folded into a const.
+        For example, in PyTorch's `to()` op, the input could be converted by `cast` op, or directly
+        be folded to const.
+
+        We only fold the var to a const when its value is known AND it doesn't have any
+        non-replaceable vars in the upstream.
+        """
+        return self.val is not None and not self.nonreplaceable_vars_upstream
+
     @property
     def sym_type(self):
         return self._sym_type
@@ -289,7 +309,7 @@ class ListVar(Var):
         elif types.is_tensor(self._elem_type):
             return self._elem_type.get_shape()
         return ()
-        
+
     def shape_str(self):
         length = "?"
         if not self.dynamic_length:
@@ -323,3 +343,55 @@ class InternalVar(Var):
         super().__init__(
             name=name, sym_type=types.unknown, sym_val=types.unknown(val)
         )
+
+
+class ComplexVar(Var):
+    """Var to handle complex data."""
+
+    __slots__ = ["_real", "_imag"]
+
+    def __init__(
+        self,
+        name,
+        sym_type,
+        sym_val=None,
+        op=None,
+        op_output_idx=None,
+        real: Optional[Var] = None,
+        imag: Optional[Var] = None,
+    ):
+        super().__init__(
+            name=name,
+            sym_type=sym_type,
+            sym_val=sym_val,
+            op=op,
+            op_output_idx=op_output_idx,
+        )
+
+        # Handle complex data types.
+        self._real: Optional[Var] = real
+        self._imag: Optional[Var] = imag
+
+    @property
+    def real(self):
+        return self._real
+
+    @property
+    def imag(self):
+        return self._imag
+
+    @real.setter
+    def real(self, real):
+        if not types.is_complex(self.dtype):
+            raise ValueError(
+                f"Only complex number can set `real`. This var is {self.dtype}."
+            )
+        self._real = real
+
+    @imag.setter
+    def imag(self, imag):
+        if not types.is_complex(self.dtype):
+            raise ValueError(
+                f"Only complex number can set `imag`. This var is {self.dtype}."
+            )
+        self._imag = imag
