@@ -19,30 +19,31 @@ def _check_visible_modules(actual, expected):
 
 
 EXPECTED_MODULES = [
-            "ClassifierConfig",
-            "ComputeUnit",
-            "EnumeratedShapes",
-            "ImageType",
-            "RangeDim",
-            "SPECIFICATION_VERSION",
-            "Shape",
-            "TensorType",
-            "colorlayout",
-            "compression_utils",
-            "convert",
-            "converters",
-            "libcoremlpython",
-            "models",
-            "proto",
-            "precision",
-            "target",
-            "utils",
-            "version",
-            "test",
-            "transform",
-            "libmodelpackage",
-            "libmilstoragepython",
-        ]
+    "ClassifierConfig",
+    "ComputeUnit",
+    "EnumeratedShapes",
+    "ImageType",
+    "RangeDim",
+    "SPECIFICATION_VERSION",
+    "Shape",
+    "TensorType",
+    "colorlayout",
+    "compression_utils",
+    "convert",
+    "converters",
+    "libcoremlpython",
+    "models",
+    "PassPipeline",
+    "proto",
+    "precision",
+    "target",
+    "utils",
+    "version",
+    "test",
+    "transform",
+    "libmodelpackage",
+    "libmilstoragepython",
+]
 
 
 class TestApiVisibilities:
@@ -60,6 +61,7 @@ class TestApiVisibilities:
             "evaluate_classifier_with_probabilities",
             "evaluate_regressor",
             "evaluate_transformer",
+            "make_pipeline",
             "load_spec",
             "rename_feature",
             "save_spec",
