@@ -51,46 +51,53 @@ def get_test_model_and_data(multi_layer=False):
 
     return model, inputs, torch_input_values, coreml_input_values
 
-def verify_model_outputs(model, compressed_model, input_values):
-    """
-    This utility functions does the following checks:
-
-    (1) Verify the output of the compressed model has the same shape / type of the original model
-    (2) The decompressed and compressed model have the same numerical outputs
-    """
-
-    # Make sure the model can be decompressed
-    decompressed_model = ct.compression_utils.decompress_weights(compressed_model)
-
-    # Validate the output shape / type
-    ref_outputs = model._mil_program.functions["main"].outputs
-    outputs = compressed_model._mil_program.functions["main"].outputs
-
-    assert len(ref_outputs) == len(outputs)
-
-    for a, b in zip(ref_outputs, outputs):
-        assert a.name == b.name
-        assert a.shape == a.shape
-        assert a.dtype == b.dtype
-
-    if ct.utils._macos_version() < (13, 0):
-        return
-
-    # Validate that the compressed model could be decompressed, and produces correct outputs
-    output_dict = compressed_model.predict(input_values)
-    de_output_dict = decompressed_model.predict(input_values)
-    for k, v in de_output_dict.items():
-        assert k in output_dict
-        np.testing.assert_allclose(v, output_dict[k])
 
 class TestCompressionUtils:
 
+    affine_quantize_weights = ct.compression_utils.affine_quantize_weights
+    palettize_weights = ct.compression_utils.palettize_weights
+    sparsify_weights = ct.compression_utils.sparsify_weights
+    decompress_weights = ct.compression_utils.decompress_weights
+
+    @staticmethod
+    def verify_model_outputs(model, compressed_model, input_values):
+        """
+        This utility functions does the following checks:
+
+        (1) Verify the output of the compressed model has the same shape / type of the original model
+        (2) The decompressed and compressed model have the same numerical outputs
+        """
+
+        # Make sure the model can be decompressed
+        decompressed_model = TestCompressionUtils.decompress_weights(compressed_model)
+
+        # Validate the output shape / type
+        ref_outputs = model._mil_program.functions["main"].outputs
+        outputs = compressed_model._mil_program.functions["main"].outputs
+
+        assert len(ref_outputs) == len(outputs)
+
+        for a, b in zip(ref_outputs, outputs):
+            assert a.name == b.name
+            assert a.shape == a.shape
+            assert a.dtype == b.dtype
+
+        if ct.utils._macos_version() < (13, 0):
+            return
+
+        # Validate that the compressed model could be decompressed, and produces correct outputs
+        output_dict = compressed_model.predict(input_values)
+        de_output_dict = decompressed_model.predict(input_values)
+        for k, v in de_output_dict.items():
+            assert k in output_dict
+            np.testing.assert_allclose(v, output_dict[k])
+
     @staticmethod
     def test_op_selector():
         model, inputs, torch_input_values, coreml_input_values = get_test_model_and_data()
         torchmodel = torch.jit.trace(model, torch_input_values)
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
-        mlmodel_no_quantized = ct.compression_utils.affine_quantize_weights(mlmodel, mode="linear", op_selector=lambda const_op: const_op.val.val.size > 1e7)
+        mlmodel_no_quantized = TestCompressionUtils.affine_quantize_weights(mlmodel, mode="linear", op_selector=lambda const_op: const_op.val.val.size > 1e7)
         expected_ops = ['cast', 'conv', 'cast']        
         assert get_op_types_in_program(mlmodel_no_quantized._mil_program) == expected_ops
 
@@ -135,13 +142,13 @@ class TestCompressionUtils:
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
         
         # we first compress the model
-        mlmodel = ct.compression_utils.palettize_weights(mlmodel, mode="kmeans", nbits=4, op_selector=lambda const_op: const_op.name == "conv_1_weight_to_fp16")
-        mlmodel = ct.compression_utils.affine_quantize_weights(mlmodel, mode="linear", op_selector=lambda const_op: const_op.name == "conv_2_weight_to_fp16")
+        mlmodel = TestCompressionUtils.palettize_weights(mlmodel, mode="kmeans", nbits=4, op_selector=lambda const_op: const_op.name == "conv_1_weight_to_fp16")
+        mlmodel = TestCompressionUtils.affine_quantize_weights(mlmodel, mode="linear", op_selector=lambda const_op: const_op.name == "conv_2_weight_to_fp16")
         expected_ops = ['constexpr_lut_to_dense', 'cast', 'conv', 'constexpr_affine_dequantize', 'conv', 'cast']
         assert get_op_types_in_program(mlmodel._mil_program) == expected_ops
 
         # decompress the model
-        decompressed_model = ct.compression_utils.decompress_weights(mlmodel)
+        decompressed_model = TestCompressionUtils.decompress_weights(mlmodel)
         assert get_op_types_in_program(decompressed_model._mil_program) == ['cast', 'conv', 'conv', 'cast']
 
         if ct.utils._macos_version() < (13, 0):
@@ -164,63 +171,63 @@ class TestCompressionUtils:
         # Test invalid mode for affine quantization
         expected_err_str = "supported for weight affine quantization. Got mode"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.affine_quantize_weights(mlmodel, mode="invalid_mode")
+            TestCompressionUtils.affine_quantize_weights(mlmodel, mode="invalid_mode")
 
         # Test invalid dtype for affine quantization
         expected_err_str = "is unsupported for affine_quantize_weight"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.affine_quantize_weights(mlmodel, dtype=np.int32)
+            TestCompressionUtils.affine_quantize_weights(mlmodel, dtype=np.int32)
 
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.affine_quantize_weights(mlmodel, dtype="int32")
+            TestCompressionUtils.affine_quantize_weights(mlmodel, dtype="int32")
 
         # Test invalid mode for weight sparsification
         expected_err_str = "supported for weight sparsification. Got mode"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.sparsify_weights(mlmodel, mode="invalid_mode")
+            TestCompressionUtils.sparsify_weights(mlmodel, mode="invalid_mode")
 
         # Test invalid threshold for weight sparsification
         expected_err_str = "Invalid value of threshold: \-1. Needs to be in \[0, inf\)"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.sparsify_weights(mlmodel, mode="threshold_based", threshold=-1)
+            TestCompressionUtils.sparsify_weights(mlmodel, mode="threshold_based", threshold=-1)
 
         # Test invalid percentile for weight sparsification
         expected_err_str = "Invalid value of target_percentile: 1.2. Needs to be in \[0, 1\]"
         with pytest.raises(ValueError, match=expected_err_str):
-           ct.compression_utils.sparsify_weights(mlmodel, mode="percentile_based", target_percentile=1.2)
+           TestCompressionUtils.sparsify_weights(mlmodel, mode="percentile_based", target_percentile=1.2)
 
         # Test invalid mode for weight palettization
         expected_err_str = "supported for weight palettization. Got mode"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="invalid_mode")
+            TestCompressionUtils.palettize_weights(mlmodel, mode="invalid_mode")
 
         # Test nbits must be provided for kmeans, uniform mode for weight palettization
         expected_err_str = "nbits must be provided for mode"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="kmeans")
+            TestCompressionUtils.palettize_weights(mlmodel, mode="kmeans")
 
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="uniform")
+            TestCompressionUtils.palettize_weights(mlmodel, mode="uniform")
 
         # Test nbits must not be provided for unique, custom mode for weight palettization
         expected_err_str = "nbits must NOT be provided for mode"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="unique", nbits=2)
+            TestCompressionUtils.palettize_weights(mlmodel, mode="unique", nbits=2)
 
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="custom", nbits=2)
+            TestCompressionUtils.palettize_weights(mlmodel, mode="custom", nbits=2)
 
         # Test lut_function must be provided for custom mode, and must not be provided otherwise
         expected_err_str = "lut_function must be None if mode is not custom, and that it cannot be None when the mode is custom."
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="custom")
+            TestCompressionUtils.palettize_weights(mlmodel, mode="custom")
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="unique", lut_function=lambda op: True)
+            TestCompressionUtils.palettize_weights(mlmodel, mode="unique", lut_function=lambda op: True)
 
         # Test lut_function must be a function obejct
         expected_err_str = "A function object must be provided as lut_function"
         with pytest.raises(ValueError, match=expected_err_str):
-            ct.compression_utils.palettize_weights(mlmodel, mode="custom", lut_function=1)
+            TestCompressionUtils.palettize_weights(mlmodel, mode="custom", lut_function=1)
 
 
     @staticmethod
@@ -236,7 +243,7 @@ class TestCompressionUtils:
         torchmodel = torch.jit.trace(model, torch_input_values)
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
 
-        mlmodel_quantized = ct.compression_utils.affine_quantize_weights(mlmodel, mode=mode, dtype=dtype)
+        mlmodel_quantized = TestCompressionUtils.affine_quantize_weights(mlmodel, mode=mode, dtype=dtype)
 
         # validate parameters
         expected_ops = ['constexpr_affine_dequantize', 'cast', 'conv', 'cast']
@@ -245,7 +252,7 @@ class TestCompressionUtils:
         quanitze_op = mlmodel_quantized._mil_program.functions["main"].find_ops(op_type="constexpr_affine_dequantize")[0]
         assert model.weight.detach().numpy().shape == quanitze_op.quantized_data.shape
 
-        verify_model_outputs(mlmodel, mlmodel_quantized, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_quantized, coreml_input_values)
 
     @staticmethod
     @pytest.mark.parametrize(
@@ -258,7 +265,7 @@ class TestCompressionUtils:
             model.weight[0][0][0][0] = 101
         torchmodel = torch.jit.trace(model, torch_input_values)
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
-        mlmodel_sparsified = ct.compression_utils.sparsify_weights(mlmodel, mode="threshold_based", threshold=threshold)
+        mlmodel_sparsified = TestCompressionUtils.sparsify_weights(mlmodel, mode="threshold_based", threshold=threshold)
 
         # validate parameters
         expected_ops = ['constexpr_sparse_to_dense', 'cast', 'conv', 'cast']
@@ -276,7 +283,7 @@ class TestCompressionUtils:
         assert sparse_to_dense_op.shape.val.tolist() == list(model.weight.detach().numpy().shape)
 
         # validate the model
-        verify_model_outputs(mlmodel, mlmodel_sparsified, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_sparsified, coreml_input_values)
 
     @staticmethod
     @pytest.mark.parametrize(
@@ -287,7 +294,7 @@ class TestCompressionUtils:
         model, inputs, torch_input_values, coreml_input_values = get_test_model_and_data()
         torchmodel = torch.jit.trace(model, torch_input_values)
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
-        mlmodel_sparsified = ct.compression_utils.sparsify_weights(mlmodel, mode="percentile_based", target_percentile=percentile)
+        mlmodel_sparsified = TestCompressionUtils.sparsify_weights(mlmodel, mode="percentile_based", target_percentile=percentile)
 
         # validate parameters        
         expected_ops = ['constexpr_sparse_to_dense', 'cast', 'conv', 'cast']
@@ -308,7 +315,7 @@ class TestCompressionUtils:
         assert sparse_to_dense_op.shape.val.tolist() == list(model.weight.detach().numpy().shape)
 
         # validate the model
-        verify_model_outputs(mlmodel, mlmodel_sparsified, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_sparsified, coreml_input_values)
 
     @staticmethod
     @pytest.mark.parametrize(
@@ -319,7 +326,7 @@ class TestCompressionUtils:
         model, inputs, torch_input_values, coreml_input_values = get_test_model_and_data()
         torchmodel = torch.jit.trace(model, torch_input_values)
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
-        mlmodel_palettized = ct.compression_utils.palettize_weights(mlmodel, nbits=4, mode=mode)
+        mlmodel_palettized = TestCompressionUtils.palettize_weights(mlmodel, nbits=4, mode=mode)
 
         # validate parameters
         expected_ops = ['constexpr_lut_to_dense', 'cast', 'conv', 'cast']
@@ -331,7 +338,7 @@ class TestCompressionUtils:
         assert lut_to_dense_op.shape.val.tolist() == list(model.weight.detach().numpy().shape)
     
         # validate the model 
-        verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
 
     @staticmethod
     def test_weight_palettization_unique_case_1():
@@ -349,7 +356,7 @@ class TestCompressionUtils:
         mlmodel = ct.convert(torchmodel, inputs=inputs, convert_to="mlprogram")
 
         # validate parameters
-        mlmodel_palettized = ct.compression_utils.palettize_weights(mlmodel, mode="unique")
+        mlmodel_palettized = TestCompressionUtils.palettize_weights(mlmodel, mode="unique")
         expected_ops = ['constexpr_lut_to_dense', 'cast', 'conv', 'constexpr_lut_to_dense', 'conv', 'cast']
         assert get_op_types_in_program(mlmodel_palettized._mil_program) == expected_ops
 
@@ -361,7 +368,7 @@ class TestCompressionUtils:
         assert lut_to_dense_op_2.shape.val.tolist() == list(model.conv_2.weight.detach().numpy().shape)
 
         # validate the model 
-        verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
 
     @staticmethod
     def test_weight_palettization_unique_case_2(caplog):
@@ -378,7 +385,7 @@ class TestCompressionUtils:
 
         # validate parameters
         # converter should warn the user that one weight is not compressed
-        mlmodel_palettized = ct.compression_utils.palettize_weights(mlmodel, mode="unique")
+        mlmodel_palettized = TestCompressionUtils.palettize_weights(mlmodel, mode="unique")
         warning_msg = "weight value cannot be represented in an 8 bits palettization. Skipped."
         assert any([warning_msg in rec.message for rec in caplog.records])
 
@@ -390,7 +397,7 @@ class TestCompressionUtils:
         assert lut_to_dense_op_1.shape.val.tolist() == list(model.conv_1.weight.detach().numpy().shape)
 
         # validate the model 
-        verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
 
     @staticmethod
     def test_weight_palettization_custom():
@@ -410,7 +417,7 @@ class TestCompressionUtils:
             indices = np.array([mapping[v] if v in mapping else 0 for v in weight]).astype(np.uint8)
             return lut, indices
 
-        mlmodel_palettized = ct.compression_utils.palettize_weights(mlmodel, mode="custom", lut_function=lut_function)
+        mlmodel_palettized = TestCompressionUtils.palettize_weights(mlmodel, mode="custom", lut_function=lut_function)
 
         # validate parameters
         expected_ops = ['constexpr_lut_to_dense', 'cast', 'conv', 'cast']
@@ -422,4 +429,4 @@ class TestCompressionUtils:
         assert lut_to_dense_op.shape.val.tolist() == list(model.weight.detach().numpy().shape)
     
         # validate the model 
-        verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
+        TestCompressionUtils.verify_model_outputs(mlmodel, mlmodel_palettized, coreml_input_values)
